#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"

#include <linux/types.h>

/* we don't want linux/time.h */
#define _LINUX_TIME_H 1
#include "videodev2.h"
#include <stdio.h>


MODULE = Video::ivtv		PACKAGE = Video::ivtv		

void
getResolution(IN int fd, OUTLIST int width, OUTLIST int height)
	INIT:
		struct v4l2_format vfmt;

	CODE:
    /* printf("Before ioctl...\n"); */
		if (ioctl(fd, VIDIOC_G_FMT, &vfmt) < 0)
		{
			/* return an invalid case to signal an error occured */
			width = height = -1;
		}
		else
		{
      /* printf("width = %d, height = %d\n", vfmt.fmt.pix.width, vfmt.fmt.pix.height); */
			width = vfmt.fmt.pix.width;
			height = vfmt.fmt.pix.height;
		}

int
setResolution(int fd, int width, int height)
	INIT:
		struct v4l2_format vfmt;

    /* make sure we have valid input values. */
    if (width < 0 || width > 720)
    {
			XSRETURN_UNDEF;
		}
		if (height < 0 || height > 576)
		{
			XSRETURN_UNDEF;
		}
	CODE:
    /* printf("Before ioctl...\n"); */
		vfmt.type = 1;  /* make sure the buf type is set for Video Capture! */
    vfmt.fmt.pix.width = width;
		vfmt.fmt.pix.height = height;
		if (ioctl(fd, VIDIOC_S_FMT, &vfmt) < 0)
		{
			/* return an invalid case to signal an error occured */
			RETVAL = 0;
		}
    else
    {
			RETVAL = 1;
		}
	OUTPUT:
		RETVAL


int
getStandard(int fd)
  INIT:
    int n;
  CODE:
    if (ioctl(fd, VIDIOC_G_STD, &n) < 0)
    {
      RETVAL = 0;
    }
    else
    {
      RETVAL = n;
    }
  OUTPUT:
    RETVAL

int
setStandard(int fd, int standard)
  CODE:
    if (ioctl(fd, VIDIOC_S_STD, &standard) < 0)
    {
      RETVAL = 0;
    }
    else
    {
      RETVAL = 1;
    }
  OUTPUT:
    RETVAL

void
enumerateStandard(IN int fd, IN_OUTLIST int index, OUTLIST int std_id, OUTLIST char *name, OUTLIST int numerator, OUTLIST int denominator, OUTLIST int framelines)
	INIT:
		struct v4l2_standard vs;

    if (index < 0)
    {
			XSRETURN_UNDEF;
		}
	CODE:
    vs.index = index;
		if (ioctl(fd, VIDIOC_ENUMSTD, &vs) < 0)
		{
			/* return an invalid case to signal an error occured */
			index = -1;
		}
		else
		{
      std_id = vs.id;
      name = vs.name;
      numerator = vs.frameperiod.numerator;
      denominator = vs.frameperiod.denominator;
      framelines = vs.framelines;
		}

int
getFrequency(int fd, int tuner)
  INIT:
    struct v4l2_frequency vf;

    if (tuner < 0)
    {
			XSRETURN_UNDEF;
		}
  CODE:
    vf.tuner = tuner;
    if (ioctl(fd, VIDIOC_G_FREQUENCY, &vf) < 0)
    {
      RETVAL = -1;
    }
    else
    {
      RETVAL = vf.frequency;
    }
  OUTPUT:
    RETVAL

int
setFrequency(int fd, int tuner, int freq)
  INIT:
    struct v4l2_frequency vf;

    if (tuner < 0)
    {
			XSRETURN_UNDEF;
		}
    if (freq < 0)
    {
			XSRETURN_UNDEF;
    }
  CODE:
    vf.tuner = tuner;
    vf.frequency = freq;
    if (ioctl(fd, VIDIOC_S_FREQUENCY, &vf) < 0)
    {
      RETVAL = 0;
    }
    else
    {
      RETVAL = 1;
    }
  OUTPUT:
    RETVAL

int
getInput(int fd)
  INIT:
    int input;
  CODE:
    if (ioctl(fd, VIDIOC_G_INPUT, &input) < 0)
    {
      RETVAL = -1;
    }
    else
    {
      RETVAL = input;
    }
  OUTPUT:
    RETVAL

int
setInput(int fd, int input)
  INIT:
    if (input < 0)
    {
			XSRETURN_UNDEF;
		}
  CODE:
    if (ioctl(fd, VIDIOC_S_INPUT, &input) < 0)
    {
      RETVAL = 0;
    }
    else
    {
      RETVAL = 1;
    }
  OUTPUT:
    RETVAL

void
enumerateInput(IN int fd, IN_OUTLIST int index, OUTLIST char *name, OUTLIST int type, OUTLIST int audioset, OUTLIST int tuner, OUTLIST int std, OUTLIST int status)
	INIT:
		struct v4l2_input vi;

    if (index < 0)
    {
			XSRETURN_UNDEF;
		}
	CODE:
    vi.index = index;
		if (ioctl(fd, VIDIOC_ENUMINPUT, &vi) < 0)
		{
			/* return an invalid case to signal an error occured */
			index = -1;
		}
		else
		{
      name = vi.name;
      type = vi.type;
      audioset = vi.audioset;
      tuner = vi.tuner;
      std = vi.std;
      status = vi.status;
		}

