# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test;
BEGIN { plan tests => 11 };
use Video::ivtv;
ok(1); # If we made it this far, we're ok.

my $dev = "/dev/video0";
open (my $tuner, "<$dev") or die "Error opening $dev!  $!\n";
my $tunerFD = fileno($tuner);
my ($oldwidth, $oldheight) = getResolution($tunerFD);
print "Width = $oldwidth, Height = $oldheight\n";
if ($oldwidth != -1 && $oldheight != -1)
{
	ok(2);
}
else
{
	print "2 failed!  Don't know how to trigger that.\n";
}

my $result = setResolution($tunerFD, 640, 480);
if (defined $result)
{
	if ($result)
	{
		my ($width, $height) = getResolution($tunerFD);
		if ($width == 640 && $height == 480)
		{
			ok(3);
      # restore the previous setting.
      $result = setResolution($tunerFD, $oldwidth, $oldheight);
		}
		else
		{
			print "Error:  width='$width', height='$height'\n";
			print "3 failed!  Don't know how to trigger that.\n";
		}
	}
	else
	{
		print "3 failed!  Don't know how to trigger that.\n";
	}
}
else
{
	print "3 failed!  Don't know how to trigger that.\n";
}

my $standard = getStandard($tunerFD);
if ($standard == 0x00003000 || $standard == 0x000000FF || $standard == 0x007F0000)
{
  ok(4);
}
else
{
  print "4 failed!  Standard = '$standard'!\n";
}

# set the Video Standard to NTSC (0x3000)
$result = setStandard($tunerFD, 0x00003000);
if ($result)
{
  my $newStandard = getStandard($tunerFD);
  if ($newStandard == $standard)
  {
    # restore the previous standard.
    setStandard($tunerFD, $standard);
    ok(5);
  }
}
else
{
	print "5 failed!  Don't know how to trigger that.\n";
}

my $freq = getFrequency($tunerFD, 0);
if ($freq != 0)
{
  ok(6);
}
else
{
  print "6 failed!  Frequency = '$freq'!\n";
}

# set the Video Frequency to 8276 (SCiFI)
$result = setFrequency($tunerFD, 0, 8276);
if ($result)
{
  # verify the frequency got set to what we want.
  $freq = getFrequency($tunerFD, 0);
  if ($freq == 8276)
  {
    ok(7);
  }
  else
  {
    print "7 failed!  Frequency = '$freq' instead of 8276!\n";
  }
}
else
{
	print "7 failed!  Don't know how to trigger that.\n";
}

# get the Video Input
my $input = getInput($tunerFD);
if ($input >= 0)
{
  print "input = '$input'\n";
  ok(8); 
}
else
{
  print "8 failed!  Don't know how to trigger that.\n";
}

# set the Video Input
$result = setInput($tunerFD, 4); # Tuner on my card.
if ($result)
{
  # verify the input got set to what I wanted.
  my $newInput = getInput($tunerFD);
  if ($newInput != 4)
  {
    print "9 failed!  Input = '$newInput' instead of 4!\n";
  }
  else
  {
    # reset the input back to what it was originally.
    setInput($tunerFD, $input);
    ok(9);
  }
}
else
{
  print "9 failed!  Don't know how to trigger that.\n";
}

# enumerate the available Standards
my $done = 0;
my $index;
for ($index=0; !$done; ++$index)
{
  my ($i, $id, $name, $numerator, $denominator, $framelines) = enumerateStandard($tunerFD, $index);
  if ($i == -1)
  {
    $done = 1;  # this index is invalid.
  }
  else
  {
    printf("%d 0x%08x %s %d/%d %d\n", $i, $id, $name, $numerator, $denominator, $framelines);
  }
}
if ($index > 0)
{
  ok(10);
}
else
{
  print "10 failed!  Don't know how to trigger that.\n";
}

# enumerate the available Inputs
$done = 0;
$index;
for ($index=0; !$done; ++$index)
{
  my ($i, $name, $type, $audioset, $tuner, $std, $status) = enumerateInput($tunerFD, $index);
  if ($i == -1)
  {
    $done = 1;  # this index is invalid.
  }
  else
  {
    printf("%d %s 0x%08x 0x%08x 0x%08x 0x%08x %d\n", $i, $name, $type, $audioset, $tuner, $std, $status);
  }
}
if ($index > 0)
{
  ok(11);
}
else
{
  print "11 failed!  Don't know how to trigger that.\n";
}


#########################

# Insert your test code below, the Test module is use()ed here so read
# its man page ( perldoc Test ) for help writing this test script.

